@@ -1,30 +1,30 @@
-/***************************************************************************
-    begin                : Thu Aug 19 2004
-    copyright            : (C) 2002 - 2004, 2008 by Michael Pyne
-    email                : michael.pyne@kde.org
-***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/**
+ * Copyright (C) 2002-2004, 2008 Michael Pyne <mpyne@kde.org>
+ *
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation; either version 2 of the License, or (at your option) any later
+ * version.
+ *
+ * This program is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along with
+ * this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "upcomingplaylist.h"
 #include "juk-exception.h"
 
-#include <kdebug.h>
-#include <kapplication.h>
-#include <kaction.h>
+#include <QAction>
 
 #include "playlistitem.h"
 #include "playlistcollection.h"
 #include "tracksequencemanager.h"
 #include "collectionlist.h"
 #include "actioncollection.h"
+#include "juk_debug.h"
 
 using namespace ActionCollection;
 
@@ -35,7 +35,7 @@ UpcomingPlaylist::UpcomingPlaylist(PlaylistCollection *collection) :
 {
     setName(i18n("Play Queue"));
     setAllowDuplicates(true);
-    setSorting(-1);
+    setSortingEnabled(false);
 }
 
 UpcomingPlaylist::~UpcomingPlaylist()
@@ -68,14 +68,14 @@ void UpcomingPlaylist::appendItems(const PlaylistItemList &itemList)
     if(itemList.isEmpty())
         return;
 
-    PlaylistItem *after = static_cast<PlaylistItem *>(lastItem());
+    PlaylistItem *after = static_cast<PlaylistItem *>(topLevelItem(topLevelItemCount() - 1));
 
     foreach(PlaylistItem *playlistItem, itemList) {
         after = createItem(playlistItem, after);
         m_playlistIndex.insert(after, playlistItem->playlist());
     }
 
-    dataChanged();
+    playlistItemsChanged();
     slotWeightDirty();
 }
 
@@ -159,7 +159,7 @@ void UpcomingPlaylist::removeIteratorOverride()
 
     setPlaying(manager()->currentItem(), true);
 
-    Watched::currentChanged();
+    Watched::currentPlayingItemChanged();
 }
 
 TrackSequenceManager *UpcomingPlaylist::manager() const
@@ -186,7 +186,8 @@ void UpcomingPlaylist::UpcomingSequenceIterator::advance()
     PlaylistItem *item = m_playlist->firstChild();
 
     if(item) {
-        PlaylistItem *next = static_cast<PlaylistItem *>(item->nextSibling());
+        QTreeWidgetItemIterator it(item);
+        PlaylistItem *next = static_cast<PlaylistItem *>(*(++it));
         m_playlist->clearItem(item);
         setCurrent(next);
     }
@@ -220,9 +221,10 @@ void UpcomingPlaylist::UpcomingSequenceIterator::setCurrent(PlaylistItem *curren
     Playlist *p = currentItem->playlist();
 
     if(p != m_playlist) {
-        PlaylistItem *i = m_playlist->createItem(currentItem, (PlaylistItem *) 0);
+        PlaylistItem *i = m_playlist->createItem(currentItem,
+                static_cast<PlaylistItem*>(nullptr));
         m_playlist->playlistIndex().insert(i, p);
-        m_playlist->dataChanged();
+        m_playlist->playlistItemsChanged();
         m_playlist->slotWeightDirty();
     }
     else {
@@ -272,7 +274,7 @@ QDataStream &operator>>(QDataStream &s, UpcomingPlaylist &p)
         if(fileName.isEmpty())
             throw BICStreamException();
 
-        newItem = p.createItem(FileHandle(fileName), newItem, false);
+        newItem = p.createItem(FileHandle(fileName), newItem);
     }
 
     return s;
